@@ -1,6 +1,6 @@
 package Getopt::EX;
 use 5.014;
-use version; our $VERSION = version->declare("v1.11.0");
+use version; our $VERSION = version->declare("v1.12.0");
 
 
 1;
@@ -12,7 +12,7 @@ Getopt::EX - Getopt Extender
 
 =head1 VERSION
 
-Version v1.11.0
+Version v1.12.0
 
 
 =head1 DESCRIPTION
@@ -190,6 +190,17 @@ or even simpler non-oo interface:
     print colorize("G", "LINE in Blue\n");
     print colorize("B", "TEXT in Green\n");
 
+=head2 L<Getopt::EX::Numbers>
+
+Parse number parameter description and parse it, then produces number
+range list or number sequence.  Number format is composed by for
+elements: C<start>, C<end>, C<step> and C<length>, like this:
+
+    1		1
+    1:3		1,2,3
+    1:20:5	1,     6,     11,       16
+    1:20:5:3	1,2,3, 6,7,8, 11,12,13, 16,17,18
+
 =head1 AUTHOR
 
 Kazumasa Utashiro
